package edu.travel.warehouse.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import edu.travel.adapter.service.country.CountryAdapter;
import edu.travel.dto.ShopWarehouseDto;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.service.SysServiceImpl;
import edu.travel.vo.BaseCountryServeVo;
import edu.travel.vo.ShopWarehouseVo;
import edu.travel.warehouse.entity.ShopWarehouse;
import edu.travel.warehouse.mapper.ShopWarehouseMapper;
import edu.travel.warehouse.service.ShopWarehouseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Service
public class ShopWarehouseServiceImpl extends SysServiceImpl<ShopWarehouseMapper, ShopWarehouse> implements ShopWarehouseService {
    @Autowired
    private CountryAdapter countryAdapter;
    /**
     * 获取仓库国家分页数据
     * @param dto
     * @return
     */
    @Override
    public RPCBaseResponse<List<ShopWarehouseVo>> getWarehouseCountryPageForm(ShopWarehouseDto dto) {
        // 查询所有库房数据
        LambdaQueryWrapper<ShopWarehouse> queryWrapper = new LambdaQueryWrapper<>();
        // 查询所有库房数据
        List<ShopWarehouse> shopWarehouseList = super.getListLink(queryWrapper);

        // 提取国家服务ID
        Set<String> countryServeIds = shopWarehouseList.stream()
                .map(ShopWarehouse::getCountryServeId)
                .collect(Collectors.toSet());

        // 创建一个 Map 以便通过 countryServeId 查询到对应的国家数据
        Map<String, BaseCountryServeVo> baseCountryServeVoMap = new HashMap<>();
        if (!countryServeIds.isEmpty()) {
            // 使用 getFormId 方法查询国家信息
            for (String countryServeId : countryServeIds) {
                RPCBaseResponse<BaseCountryServeVo> response = countryAdapter.getFormId(countryServeId);
                if (response != null && response.getData() != null) {
                    baseCountryServeVoMap.put(countryServeId, response.getData());
                }
            }
        }

        // 链接库房信息与国家信息
        List<ShopWarehouseVo> shopWarehouseVoList = shopWarehouseList.stream()
                .map(shopWarehouse -> {
                    ShopWarehouseVo shopWarehouseVo = new ShopWarehouseVo();
                    shopWarehouseVo.setId(shopWarehouse.getId());
                    shopWarehouseVo.setCountryServeId(shopWarehouse.getCountryServeId());
                    shopWarehouseVo.setMap(new HashMap<>()); // 创建一个新 Map
                    // 将国家信息放入 Map 中
                    if (baseCountryServeVoMap.containsKey(shopWarehouse.getCountryServeId())) {
                        shopWarehouseVo.getMap().put("country", baseCountryServeVoMap.get(shopWarehouse.getCountryServeId()));
                    }
                    return shopWarehouseVo;
                })
                .collect(Collectors.toList());

        // 返回所有库房与国家信息
        return new RPCBaseResponse<>(200, "SUCCESS", shopWarehouseVoList);
    }

}
